# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: managed_secrets.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15managed_secrets.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\x18ManagedSecretLogsRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe7\x01\n\x19ManagedSecretLogsResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12=\n\x13managed_secret_logs\x18\x02 \x03(\x0b\x32\x14.v1.ManagedSecretLogB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x18ManagedSecretListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xbe\x01\n\x19ManagedSecretListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x36\n\x0fmanaged_secrets\x18\x02 \x03(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x88\x01\n\x1cManagedSecretRetrieveRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npublic_key\x18\x03 \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xee\x01\n\x1dManagedSecretRetrieveResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0emanaged_secret\x18\x02 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"h\n\x1cManagedSecretValidateRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xf4\x01\n\x1dManagedSecretValidateResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05valid\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\x12 \n\x0cinvalid_info\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"c\n\x17ManagedSecretGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe9\x01\n\x18ManagedSecretGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0emanaged_secret\x18\x02 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x88\x01\n\x1aManagedSecretCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x35\n\x0emanaged_secret\x18\x02 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xef\x01\n\x1bManagedSecretCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0emanaged_secret\x18\x02 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x01\n\x1aManagedSecretUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x35\n\x0emanaged_secret\x18\x03 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xef\x01\n\x1bManagedSecretUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0emanaged_secret\x18\x02 \x01(\x0b\x32\x11.v1.ManagedSecretB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"j\n\x1aManagedSecretRotateRequest\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.GenericRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb9\x01\n\x1bManagedSecretRotateResponse\x12\x35\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.v1.GenericResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x1aManagedSecretDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xac\x01\n\x1bManagedSecretDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xaf\x02\n\x10ManagedSecretLog\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x10secret_engine_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12*\n\x11managed_secret_id\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x06\x61\x63tion\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1e\n\x05\x64\x65\x62ug\x18\x07 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xcf\x03\n\rManagedSecret\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12)\n\x10secret_engine_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1e\n\x05value\x18\x04 \x01(\x0c\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xf0\xf3\xb3\x07\x01\x12*\n\x11secret_store_path\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12\x38\n\x06policy\x18\x06 \x01(\x0b\x32\x17.v1.ManagedSecretPolicyB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x0flast_rotated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12?\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12\x1f\n\x06\x63onfig\x18\n \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xad\x01\n\x13ManagedSecretPolicy\x12\x44\n\x0frotation_policy\x18\x01 \x01(\x0b\x32\x1f.v1.ManagedSecretRotationPolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x0fpassword_policy\x18\x02 \x01(\x0b\x32\x1f.v1.ManagedSecretPasswordPolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xf8\x01\n\x1bManagedSecretPasswordPolicy\x12\x1a\n\x06length\x18\x01 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12\x65xclude_upper_case\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nnum_digits\x18\x03 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bnum_symbols\x18\x04 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0c\x61llow_repeat\x18\x05 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12\x65xclude_characters\x18\x06 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\")\n\x1bManagedSecretRotationPolicy:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xd8\x0b\n\x0eManagedSecrets\x12o\n\x04List\x12\x1c.v1.ManagedSecretListRequest\x1a\x1d.v1.ManagedSecretListResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/managed-secrets\x12|\n\x0bListByActor\x12\x1c.v1.ManagedSecretListRequest\x1a\x1d.v1.ManagedSecretListResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/managed-secrets/actor\x12v\n\x06\x43reate\x12\x1e.v1.ManagedSecretCreateRequest\x1a\x1f.v1.ManagedSecretCreateResponse\"+\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/managed-secrets\x12z\n\x06Update\x12\x1e.v1.ManagedSecretUpdateRequest\x1a\x1f.v1.ManagedSecretUpdateResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/managed-secrets/{id}\x12\x81\x01\n\x06Rotate\x12\x1e.v1.ManagedSecretRotateRequest\x1a\x1f.v1.ManagedSecretRotateResponse\"6\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/managed-secrets/{id}/rotate\x12}\n\x06\x44\x65lete\x12\x1e.v1.ManagedSecretDeleteRequest\x1a\x1f.v1.ManagedSecretDeleteResponse\"2\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/managed-secrets/{id}\x12\x88\x01\n\x0b\x46orceDelete\x12\x1e.v1.ManagedSecretDeleteRequest\x1a\x1f.v1.ManagedSecretDeleteResponse\"8\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/managed-secrets/{id}/force\x12q\n\x03Get\x12\x1b.v1.ManagedSecretGetRequest\x1a\x1c.v1.ManagedSecretGetResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/managed-secrets/{id}\x12\x8b\x01\n\x08Retrieve\x12 .v1.ManagedSecretRetrieveRequest\x1a!.v1.ManagedSecretRetrieveResponse\":\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\'\xaa\xf3\xb3\x07\"/v1/managed-secrets/{id}/sensitive\x12\x8a\x01\n\x08Validate\x12 .v1.ManagedSecretValidateRequest\x1a!.v1.ManagedSecretValidateResponse\"9\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07&\xaa\xf3\xb3\x07!/v1/managed-secrets/{id}/validate\x12t\n\x04Logs\x12\x1c.v1.ManagedSecretLogsRequest\x1a\x1d.v1.ManagedSecretLogsResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/managed-secrets-logs\x1aQ\xca\xf9\xb3\x07\x12\xc2\xf9\xb3\x07\rManagedSecret\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03ms-\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42j\n\x19\x63om.strongdm.api.plumbingB\x16ManagedSecretsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_MANAGEDSECRETLOGSREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretLogsRequest']
_MANAGEDSECRETLOGSRESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretLogsResponse']
_MANAGEDSECRETLISTREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretListRequest']
_MANAGEDSECRETLISTRESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretListResponse']
_MANAGEDSECRETRETRIEVEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretRetrieveRequest']
_MANAGEDSECRETRETRIEVERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretRetrieveResponse']
_MANAGEDSECRETVALIDATEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretValidateRequest']
_MANAGEDSECRETVALIDATERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretValidateResponse']
_MANAGEDSECRETGETREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretGetRequest']
_MANAGEDSECRETGETRESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretGetResponse']
_MANAGEDSECRETCREATEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretCreateRequest']
_MANAGEDSECRETCREATERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretCreateResponse']
_MANAGEDSECRETUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretUpdateRequest']
_MANAGEDSECRETUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretUpdateResponse']
_MANAGEDSECRETROTATEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretRotateRequest']
_MANAGEDSECRETROTATERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretRotateResponse']
_MANAGEDSECRETDELETEREQUEST = DESCRIPTOR.message_types_by_name['ManagedSecretDeleteRequest']
_MANAGEDSECRETDELETERESPONSE = DESCRIPTOR.message_types_by_name['ManagedSecretDeleteResponse']
_MANAGEDSECRETLOG = DESCRIPTOR.message_types_by_name['ManagedSecretLog']
_MANAGEDSECRET = DESCRIPTOR.message_types_by_name['ManagedSecret']
_MANAGEDSECRETPOLICY = DESCRIPTOR.message_types_by_name['ManagedSecretPolicy']
_MANAGEDSECRETPASSWORDPOLICY = DESCRIPTOR.message_types_by_name['ManagedSecretPasswordPolicy']
_MANAGEDSECRETROTATIONPOLICY = DESCRIPTOR.message_types_by_name['ManagedSecretRotationPolicy']
ManagedSecretLogsRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETLOGSREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretLogsRequest)
  })
_sym_db.RegisterMessage(ManagedSecretLogsRequest)

ManagedSecretLogsResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETLOGSRESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretLogsResponse)
  })
_sym_db.RegisterMessage(ManagedSecretLogsResponse)

ManagedSecretListRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretListRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETLISTREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretListRequest)
  })
_sym_db.RegisterMessage(ManagedSecretListRequest)

ManagedSecretListResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretListResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETLISTRESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretListResponse)
  })
_sym_db.RegisterMessage(ManagedSecretListResponse)

ManagedSecretRetrieveRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETRETRIEVEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretRetrieveRequest)
  })
_sym_db.RegisterMessage(ManagedSecretRetrieveRequest)

ManagedSecretRetrieveResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretRetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETRETRIEVERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretRetrieveResponse)
  })
_sym_db.RegisterMessage(ManagedSecretRetrieveResponse)

ManagedSecretValidateRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETVALIDATEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretValidateRequest)
  })
_sym_db.RegisterMessage(ManagedSecretValidateRequest)

ManagedSecretValidateResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretValidateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETVALIDATERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretValidateResponse)
  })
_sym_db.RegisterMessage(ManagedSecretValidateResponse)

ManagedSecretGetRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETGETREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretGetRequest)
  })
_sym_db.RegisterMessage(ManagedSecretGetRequest)

ManagedSecretGetResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETGETRESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretGetResponse)
  })
_sym_db.RegisterMessage(ManagedSecretGetResponse)

ManagedSecretCreateRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETCREATEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretCreateRequest)
  })
_sym_db.RegisterMessage(ManagedSecretCreateRequest)

ManagedSecretCreateResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETCREATERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretCreateResponse)
  })
_sym_db.RegisterMessage(ManagedSecretCreateResponse)

ManagedSecretUpdateRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETUPDATEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretUpdateRequest)
  })
_sym_db.RegisterMessage(ManagedSecretUpdateRequest)

ManagedSecretUpdateResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETUPDATERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretUpdateResponse)
  })
_sym_db.RegisterMessage(ManagedSecretUpdateResponse)

ManagedSecretRotateRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretRotateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETROTATEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretRotateRequest)
  })
_sym_db.RegisterMessage(ManagedSecretRotateRequest)

ManagedSecretRotateResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretRotateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETROTATERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretRotateResponse)
  })
_sym_db.RegisterMessage(ManagedSecretRotateResponse)

ManagedSecretDeleteRequest = _reflection.GeneratedProtocolMessageType('ManagedSecretDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETDELETEREQUEST,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretDeleteRequest)
  })
_sym_db.RegisterMessage(ManagedSecretDeleteRequest)

ManagedSecretDeleteResponse = _reflection.GeneratedProtocolMessageType('ManagedSecretDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETDELETERESPONSE,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretDeleteResponse)
  })
_sym_db.RegisterMessage(ManagedSecretDeleteResponse)

ManagedSecretLog = _reflection.GeneratedProtocolMessageType('ManagedSecretLog', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETLOG,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretLog)
  })
_sym_db.RegisterMessage(ManagedSecretLog)

ManagedSecret = _reflection.GeneratedProtocolMessageType('ManagedSecret', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRET,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecret)
  })
_sym_db.RegisterMessage(ManagedSecret)

ManagedSecretPolicy = _reflection.GeneratedProtocolMessageType('ManagedSecretPolicy', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETPOLICY,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretPolicy)
  })
_sym_db.RegisterMessage(ManagedSecretPolicy)

ManagedSecretPasswordPolicy = _reflection.GeneratedProtocolMessageType('ManagedSecretPasswordPolicy', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETPASSWORDPOLICY,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretPasswordPolicy)
  })
_sym_db.RegisterMessage(ManagedSecretPasswordPolicy)

ManagedSecretRotationPolicy = _reflection.GeneratedProtocolMessageType('ManagedSecretRotationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSECRETROTATIONPOLICY,
  '__module__' : 'managed_secrets_pb2'
  # @@protoc_insertion_point(class_scope:v1.ManagedSecretRotationPolicy)
  })
_sym_db.RegisterMessage(ManagedSecretRotationPolicy)

_MANAGEDSECRETS = DESCRIPTOR.services_by_name['ManagedSecrets']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\026ManagedSecretsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _MANAGEDSECRETLOGSREQUEST.fields_by_name['filter']._options = None
  _MANAGEDSECRETLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETLOGSREQUEST._options = None
  _MANAGEDSECRETLOGSREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETLOGSRESPONSE.fields_by_name['managed_secret_logs']._options = None
  _MANAGEDSECRETLOGSRESPONSE.fields_by_name['managed_secret_logs']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _MANAGEDSECRETLOGSRESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETLOGSRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETLOGSRESPONSE._options = None
  _MANAGEDSECRETLOGSRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETLISTREQUEST.fields_by_name['filter']._options = None
  _MANAGEDSECRETLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETLISTREQUEST._options = None
  _MANAGEDSECRETLISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETLISTRESPONSE.fields_by_name['managed_secrets']._options = None
  _MANAGEDSECRETLISTRESPONSE.fields_by_name['managed_secrets']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _MANAGEDSECRETLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETLISTRESPONSE._options = None
  _MANAGEDSECRETLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETRETRIEVEREQUEST.fields_by_name['id']._options = None
  _MANAGEDSECRETRETRIEVEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETRETRIEVEREQUEST.fields_by_name['public_key']._options = None
  _MANAGEDSECRETRETRIEVEREQUEST.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\000'
  _MANAGEDSECRETRETRIEVEREQUEST._options = None
  _MANAGEDSECRETRETRIEVEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETRETRIEVERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETRETRIEVERESPONSE._options = None
  _MANAGEDSECRETRETRIEVERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETVALIDATEREQUEST.fields_by_name['id']._options = None
  _MANAGEDSECRETVALIDATEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETVALIDATEREQUEST._options = None
  _MANAGEDSECRETVALIDATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['valid']._options = None
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['valid']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['invalid_info']._options = None
  _MANAGEDSECRETVALIDATERESPONSE.fields_by_name['invalid_info']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETVALIDATERESPONSE._options = None
  _MANAGEDSECRETVALIDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETGETREQUEST.fields_by_name['id']._options = None
  _MANAGEDSECRETGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETGETREQUEST._options = None
  _MANAGEDSECRETGETREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETGETRESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETGETRESPONSE.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETGETRESPONSE.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETGETRESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETGETRESPONSE._options = None
  _MANAGEDSECRETGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETCREATEREQUEST.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETCREATEREQUEST.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETCREATEREQUEST._options = None
  _MANAGEDSECRETCREATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETCREATERESPONSE._options = None
  _MANAGEDSECRETCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETUPDATEREQUEST.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETUPDATEREQUEST.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETUPDATEREQUEST._options = None
  _MANAGEDSECRETUPDATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['managed_secret']._options = None
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['managed_secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETUPDATERESPONSE._options = None
  _MANAGEDSECRETUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETROTATEREQUEST.fields_by_name['id']._options = None
  _MANAGEDSECRETROTATEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETROTATEREQUEST._options = None
  _MANAGEDSECRETROTATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETROTATERESPONSE.fields_by_name['meta']._options = None
  _MANAGEDSECRETROTATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETROTATERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETROTATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETROTATERESPONSE._options = None
  _MANAGEDSECRETROTATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETDELETEREQUEST.fields_by_name['id']._options = None
  _MANAGEDSECRETDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETDELETEREQUEST._options = None
  _MANAGEDSECRETDELETEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _MANAGEDSECRETDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _MANAGEDSECRETDELETERESPONSE._options = None
  _MANAGEDSECRETDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['id']._options = None
  _MANAGEDSECRETLOG.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['created_at']._options = None
  _MANAGEDSECRETLOG.fields_by_name['created_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['secret_engine_id']._options = None
  _MANAGEDSECRETLOG.fields_by_name['secret_engine_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['managed_secret_id']._options = None
  _MANAGEDSECRETLOG.fields_by_name['managed_secret_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['account_id']._options = None
  _MANAGEDSECRETLOG.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['action']._options = None
  _MANAGEDSECRETLOG.fields_by_name['action']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRETLOG.fields_by_name['debug']._options = None
  _MANAGEDSECRETLOG.fields_by_name['debug']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRETLOG._options = None
  _MANAGEDSECRETLOG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['id']._options = None
  _MANAGEDSECRET.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['name']._options = None
  _MANAGEDSECRET.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['secret_engine_id']._options = None
  _MANAGEDSECRET.fields_by_name['secret_engine_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['value']._options = None
  _MANAGEDSECRET.fields_by_name['value']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\360\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['secret_store_path']._options = None
  _MANAGEDSECRET.fields_by_name['secret_store_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _MANAGEDSECRET.fields_by_name['policy']._options = None
  _MANAGEDSECRET.fields_by_name['policy']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['tags']._options = None
  _MANAGEDSECRET.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRET.fields_by_name['last_rotated_at']._options = None
  _MANAGEDSECRET.fields_by_name['last_rotated_at']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _MANAGEDSECRET.fields_by_name['expires_at']._options = None
  _MANAGEDSECRET.fields_by_name['expires_at']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _MANAGEDSECRET.fields_by_name['config']._options = None
  _MANAGEDSECRET.fields_by_name['config']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _MANAGEDSECRET._options = None
  _MANAGEDSECRET._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETPOLICY.fields_by_name['rotation_policy']._options = None
  _MANAGEDSECRETPOLICY.fields_by_name['rotation_policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPOLICY.fields_by_name['password_policy']._options = None
  _MANAGEDSECRETPOLICY.fields_by_name['password_policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPOLICY._options = None
  _MANAGEDSECRETPOLICY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['length']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['length']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['exclude_upper_case']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['exclude_upper_case']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['num_digits']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['num_digits']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['num_symbols']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['num_symbols']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['allow_repeat']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['allow_repeat']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['exclude_characters']._options = None
  _MANAGEDSECRETPASSWORDPOLICY.fields_by_name['exclude_characters']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MANAGEDSECRETPASSWORDPOLICY._options = None
  _MANAGEDSECRETPASSWORDPOLICY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETROTATIONPOLICY._options = None
  _MANAGEDSECRETROTATIONPOLICY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _MANAGEDSECRETS._options = None
  _MANAGEDSECRETS._serialized_options = b'\312\371\263\007\022\302\371\263\007\rManagedSecret\312\371\263\007\010\322\371\263\007\003ms-\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\350\371\263\007\001'
  _MANAGEDSECRETS.methods_by_name['List']._options = None
  _MANAGEDSECRETS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/managed-secrets'
  _MANAGEDSECRETS.methods_by_name['ListByActor']._options = None
  _MANAGEDSECRETS.methods_by_name['ListByActor']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\036\252\363\263\007\031/v1/managed-secrets/actor'
  _MANAGEDSECRETS.methods_by_name['Create']._options = None
  _MANAGEDSECRETS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\030\252\363\263\007\023/v1/managed-secrets'
  _MANAGEDSECRETS.methods_by_name['Update']._options = None
  _MANAGEDSECRETS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\035\252\363\263\007\030/v1/managed-secrets/{id}'
  _MANAGEDSECRETS.methods_by_name['Rotate']._options = None
  _MANAGEDSECRETS.methods_by_name['Rotate']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007$\252\363\263\007\037/v1/managed-secrets/{id}/rotate'
  _MANAGEDSECRETS.methods_by_name['Delete']._options = None
  _MANAGEDSECRETS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\035\252\363\263\007\030/v1/managed-secrets/{id}'
  _MANAGEDSECRETS.methods_by_name['ForceDelete']._options = None
  _MANAGEDSECRETS.methods_by_name['ForceDelete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007#\252\363\263\007\036/v1/managed-secrets/{id}/force'
  _MANAGEDSECRETS.methods_by_name['Get']._options = None
  _MANAGEDSECRETS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/managed-secrets/{id}'
  _MANAGEDSECRETS.methods_by_name['Retrieve']._options = None
  _MANAGEDSECRETS.methods_by_name['Retrieve']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\'\252\363\263\007\"/v1/managed-secrets/{id}/sensitive'
  _MANAGEDSECRETS.methods_by_name['Validate']._options = None
  _MANAGEDSECRETS.methods_by_name['Validate']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007&\252\363\263\007!/v1/managed-secrets/{id}/validate'
  _MANAGEDSECRETS.methods_by_name['Logs']._options = None
  _MANAGEDSECRETS.methods_by_name['Logs']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/managed-secrets-logs'
  _MANAGEDSECRETLOGSREQUEST._serialized_start=101
  _MANAGEDSECRETLOGSREQUEST._serialized_end=206
  _MANAGEDSECRETLOGSRESPONSE._serialized_start=209
  _MANAGEDSECRETLOGSRESPONSE._serialized_end=440
  _MANAGEDSECRETLISTREQUEST._serialized_start=442
  _MANAGEDSECRETLISTREQUEST._serialized_end=547
  _MANAGEDSECRETLISTRESPONSE._serialized_start=550
  _MANAGEDSECRETLISTRESPONSE._serialized_end=740
  _MANAGEDSECRETRETRIEVEREQUEST._serialized_start=743
  _MANAGEDSECRETRETRIEVEREQUEST._serialized_end=879
  _MANAGEDSECRETRETRIEVERESPONSE._serialized_start=882
  _MANAGEDSECRETRETRIEVERESPONSE._serialized_end=1120
  _MANAGEDSECRETVALIDATEREQUEST._serialized_start=1122
  _MANAGEDSECRETVALIDATEREQUEST._serialized_end=1226
  _MANAGEDSECRETVALIDATERESPONSE._serialized_start=1229
  _MANAGEDSECRETVALIDATERESPONSE._serialized_end=1473
  _MANAGEDSECRETGETREQUEST._serialized_start=1475
  _MANAGEDSECRETGETREQUEST._serialized_end=1574
  _MANAGEDSECRETGETRESPONSE._serialized_start=1577
  _MANAGEDSECRETGETRESPONSE._serialized_end=1810
  _MANAGEDSECRETCREATEREQUEST._serialized_start=1813
  _MANAGEDSECRETCREATEREQUEST._serialized_end=1949
  _MANAGEDSECRETCREATERESPONSE._serialized_start=1952
  _MANAGEDSECRETCREATERESPONSE._serialized_end=2191
  _MANAGEDSECRETUPDATEREQUEST._serialized_start=2194
  _MANAGEDSECRETUPDATEREQUEST._serialized_end=2342
  _MANAGEDSECRETUPDATERESPONSE._serialized_start=2345
  _MANAGEDSECRETUPDATERESPONSE._serialized_end=2584
  _MANAGEDSECRETROTATEREQUEST._serialized_start=2586
  _MANAGEDSECRETROTATEREQUEST._serialized_end=2692
  _MANAGEDSECRETROTATERESPONSE._serialized_start=2695
  _MANAGEDSECRETROTATERESPONSE._serialized_end=2880
  _MANAGEDSECRETDELETEREQUEST._serialized_start=2882
  _MANAGEDSECRETDELETEREQUEST._serialized_end=2987
  _MANAGEDSECRETDELETERESPONSE._serialized_start=2990
  _MANAGEDSECRETDELETERESPONSE._serialized_end=3162
  _MANAGEDSECRETLOG._serialized_start=3165
  _MANAGEDSECRETLOG._serialized_end=3468
  _MANAGEDSECRET._serialized_start=3471
  _MANAGEDSECRET._serialized_end=3934
  _MANAGEDSECRETPOLICY._serialized_start=3937
  _MANAGEDSECRETPOLICY._serialized_end=4110
  _MANAGEDSECRETPASSWORDPOLICY._serialized_start=4113
  _MANAGEDSECRETPASSWORDPOLICY._serialized_end=4361
  _MANAGEDSECRETROTATIONPOLICY._serialized_start=4363
  _MANAGEDSECRETROTATIONPOLICY._serialized_end=4404
  _MANAGEDSECRETS._serialized_start=4407
  _MANAGEDSECRETS._serialized_end=5903
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\roptions.proto\x12\x02v1\x1a google/protobuf/descriptor.proto\"9\n\x0b\x46ileOptions\x12\x11\n\x07targets\x18\xc4\xc1v \x03(\t:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"\xbd\x01\n\x0eServiceOptions\x12\x13\n\tmain_noun\x18\x98\xbfv \x01(\t\x12\x13\n\tid_prefix\x18\x9a\xbfv \x01(\t\x12\x11\n\x07targets\x18\x99\xbfv \x03(\t\x12#\n\x19\x64isable_snapshot_vertical\x18\x9b\xbfv \x01(\x08\x12\x30\n&json_gateway_register_with_constructor\x18\x9d\xbfv \x01(\x08:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"\x9d\x01\n\rMethodOptions\x12\x10\n\x06method\x18\xb4\xbev \x01(\t\x12\r\n\x03url\x18\xb5\xbev \x01(\t\x12\x1a\n\x10\x64\x65precation_date\x18\xb6\xbev \x01(\t\x12\x11\n\x07targets\x18\x99\xbfv \x03(\t\x12#\n\x06\x63ustom\x18\xb9\xbev \x01(\x0b\x32\x11.v1.CustomOptions:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"\xf2\x01\n\x0eMessageOptions\x12\x13\n\tporcelain\x18\xb5\xbev \x01(\x08\x12\x0f\n\x05\x65rror\x18\xb6\xbev \x01(\x05\x12\x17\n\roptions_field\x18\xb7\xbev \x01(\t\x12\x11\n\x07targets\x18\xba\xbev \x03(\t\x12+\n\x0eterraform_docs\x18\xb8\xbev \x01(\x0b\x32\x11.v1.TerraformDocs\x12#\n\x06\x63ustom\x18\xb9\xbev \x01(\x0b\x32\x11.v1.CustomOptions\x12#\n\x19terraform_datasource_only\x18\xbb\xbev \x01(\x08:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"W\n\x0cOneofOptions\x12\x17\n\rcommon_fields\x18\x85\xbfv \x03(\t\x12\x15\n\x0b\x66ilter_name\x18\x86\xbfv \x01(\t:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"\xa5\x04\n\x0c\x46ieldOptions\x12\x13\n\tporcelain\x18\xb6\xbev \x01(\x08\x12\x12\n\x08iterable\x18\xb7\xbev \x01(\x08\x12\x12\n\x08required\x18\xb8\xbev \x01(\x08\x12\x14\n\nwrite_only\x18\xbd\xbev \x01(\x08\x12\x13\n\tread_only\x18\xc3\xbev \x01(\x08\x12\x17\n\ris_credential\x18\xc4\xbev \x01(\x08\x12\x11\n\x07targets\x18\xc6\xbev \x03(\t\x12\x1d\n\x13terraform_force_new\x18\xbc\xbev \x01(\x08\x12\x1d\n\x13terraform_sensitive\x18\xbe\xbev \x01(\x08\x12&\n\x1cterraform_diff_suppress_func\x18\xc7\xbev \x01(\t\x12\x1c\n\x12terraform_computed\x18\xca\xbev \x01(\x08\x12#\n\x06\x63ustom\x18\xb9\xbev \x01(\x0b\x32\x11.v1.CustomOptions\x12\x44\n\x12read_only_override\x18\xc0\xbev \x03(\x0b\x32&.v1.FieldOptions.ReadOnlyOverrideEntry\x12\x13\n\tcondition\x18\xcb\xbev \x01(\t\x12\x14\n\nconditions\x18\xcd\xbev \x03(\t\x12\x15\n\x0b\x65xpect_file\x18\xcc\xbev \x01(\x08\x1a\x37\n\x15ReadOnlyOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"^\n\x0b\x45numOptions\x12\x11\n\x07targets\x18\xd2\xbev \x03(\t\x12#\n\x06\x63ustom\x18\xb9\xbev \x01(\x0b\x32\x11.v1.CustomOptions:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"\x8f\x05\n\rCustomOptions\x12\x13\n\tconverter\x18\xbd\xbev \x01(\t\x12O\n\x17porcelain_type_override\x18\xbe\xbev \x03(\x0b\x32,.v1.CustomOptions.PorcelainTypeOverrideEntry\x12O\n\x17porcelain_name_override\x18\xc8\xbev \x03(\x0b\x32,.v1.CustomOptions.PorcelainNameOverrideEntry\x12\x42\n\x10\x63omment_override\x18\xd3\xbev \x03(\x0b\x32&.v1.CustomOptions.CommentOverrideEntry\x12H\n\x13\x64\x65precated_override\x18\xc0\xbev \x03(\x0b\x32).v1.CustomOptions.DeprecatedOverrideEntry\x12\x1d\n\x13terraform_elem_type\x18\xbf\xbev \x01(\t\x12\x12\n\x08unstable\x18\xc1\xbev \x01(\x08\x1a<\n\x1aPorcelainTypeOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a<\n\x1aPorcelainNameOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14\x43ommentOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17\x44\x65precatedOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway\"m\n\rTerraformDocs\x12\x1f\n\x15resource_example_path\x18\xb4\xbev \x01(\t\x12\"\n\x18\x64\x61ta_source_example_path\x18\xb5\xbev \x01(\t:\x17\xfa\xf8\xb3\x07\x12\xd2\xf3\xb3\x07\r!json_gateway:E\n\x0c\x66ile_options\x12\x1c.google.protobuf.FileOptions\x18\xa8\xc2v \x01(\x0b\x32\x0f.v1.FileOptions:N\n\x0fservice_options\x12\x1f.google.protobuf.ServiceOptions\x18\x99\xbfv \x01(\x0b\x32\x12.v1.ServiceOptions:K\n\x0emethod_options\x12\x1e.google.protobuf.MethodOptions\x18\x90\xbfv \x01(\x0b\x32\x11.v1.MethodOptions:N\n\x0fmessage_options\x12\x1f.google.protobuf.MessageOptions\x18\x8f\xbfv \x01(\x0b\x32\x12.v1.MessageOptions:H\n\roneof_options\x12\x1d.google.protobuf.OneofOptions\x18\x85\xbfv \x01(\x0b\x32\x10.v1.OneofOptions:H\n\rfield_options\x12\x1d.google.protobuf.FieldOptions\x18\x8e\xbfv \x01(\x0b\x32\x10.v1.FieldOptions:E\n\x0c\x65num_options\x12\x1c.google.protobuf.EnumOptions\x18\x86\xbfv \x01(\x0b\x32\x0f.v1.EnumOptionsBR\n\x19\x63om.strongdm.api.plumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')


FILE_OPTIONS_FIELD_NUMBER = 1941800
file_options = DESCRIPTOR.extensions_by_name['file_options']
SERVICE_OPTIONS_FIELD_NUMBER = 1941401
service_options = DESCRIPTOR.extensions_by_name['service_options']
METHOD_OPTIONS_FIELD_NUMBER = 1941392
method_options = DESCRIPTOR.extensions_by_name['method_options']
MESSAGE_OPTIONS_FIELD_NUMBER = 1941391
message_options = DESCRIPTOR.extensions_by_name['message_options']
ONEOF_OPTIONS_FIELD_NUMBER = 1941381
oneof_options = DESCRIPTOR.extensions_by_name['oneof_options']
FIELD_OPTIONS_FIELD_NUMBER = 1941390
field_options = DESCRIPTOR.extensions_by_name['field_options']
ENUM_OPTIONS_FIELD_NUMBER = 1941382
enum_options = DESCRIPTOR.extensions_by_name['enum_options']

_FILEOPTIONS = DESCRIPTOR.message_types_by_name['FileOptions']
_SERVICEOPTIONS = DESCRIPTOR.message_types_by_name['ServiceOptions']
_METHODOPTIONS = DESCRIPTOR.message_types_by_name['MethodOptions']
_MESSAGEOPTIONS = DESCRIPTOR.message_types_by_name['MessageOptions']
_ONEOFOPTIONS = DESCRIPTOR.message_types_by_name['OneofOptions']
_FIELDOPTIONS = DESCRIPTOR.message_types_by_name['FieldOptions']
_FIELDOPTIONS_READONLYOVERRIDEENTRY = _FIELDOPTIONS.nested_types_by_name['ReadOnlyOverrideEntry']
_ENUMOPTIONS = DESCRIPTOR.message_types_by_name['EnumOptions']
_CUSTOMOPTIONS = DESCRIPTOR.message_types_by_name['CustomOptions']
_CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY = _CUSTOMOPTIONS.nested_types_by_name['PorcelainTypeOverrideEntry']
_CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY = _CUSTOMOPTIONS.nested_types_by_name['PorcelainNameOverrideEntry']
_CUSTOMOPTIONS_COMMENTOVERRIDEENTRY = _CUSTOMOPTIONS.nested_types_by_name['CommentOverrideEntry']
_CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY = _CUSTOMOPTIONS.nested_types_by_name['DeprecatedOverrideEntry']
_TERRAFORMDOCS = DESCRIPTOR.message_types_by_name['TerraformDocs']
FileOptions = _reflection.GeneratedProtocolMessageType('FileOptions', (_message.Message,), {
  'DESCRIPTOR' : _FILEOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.FileOptions)
  })
_sym_db.RegisterMessage(FileOptions)

ServiceOptions = _reflection.GeneratedProtocolMessageType('ServiceOptions', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.ServiceOptions)
  })
_sym_db.RegisterMessage(ServiceOptions)

MethodOptions = _reflection.GeneratedProtocolMessageType('MethodOptions', (_message.Message,), {
  'DESCRIPTOR' : _METHODOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.MethodOptions)
  })
_sym_db.RegisterMessage(MethodOptions)

MessageOptions = _reflection.GeneratedProtocolMessageType('MessageOptions', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.MessageOptions)
  })
_sym_db.RegisterMessage(MessageOptions)

OneofOptions = _reflection.GeneratedProtocolMessageType('OneofOptions', (_message.Message,), {
  'DESCRIPTOR' : _ONEOFOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.OneofOptions)
  })
_sym_db.RegisterMessage(OneofOptions)

FieldOptions = _reflection.GeneratedProtocolMessageType('FieldOptions', (_message.Message,), {

  'ReadOnlyOverrideEntry' : _reflection.GeneratedProtocolMessageType('ReadOnlyOverrideEntry', (_message.Message,), {
    'DESCRIPTOR' : _FIELDOPTIONS_READONLYOVERRIDEENTRY,
    '__module__' : 'options_pb2'
    # @@protoc_insertion_point(class_scope:v1.FieldOptions.ReadOnlyOverrideEntry)
    })
  ,
  'DESCRIPTOR' : _FIELDOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.FieldOptions)
  })
_sym_db.RegisterMessage(FieldOptions)
_sym_db.RegisterMessage(FieldOptions.ReadOnlyOverrideEntry)

EnumOptions = _reflection.GeneratedProtocolMessageType('EnumOptions', (_message.Message,), {
  'DESCRIPTOR' : _ENUMOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.EnumOptions)
  })
_sym_db.RegisterMessage(EnumOptions)

CustomOptions = _reflection.GeneratedProtocolMessageType('CustomOptions', (_message.Message,), {

  'PorcelainTypeOverrideEntry' : _reflection.GeneratedProtocolMessageType('PorcelainTypeOverrideEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY,
    '__module__' : 'options_pb2'
    # @@protoc_insertion_point(class_scope:v1.CustomOptions.PorcelainTypeOverrideEntry)
    })
  ,

  'PorcelainNameOverrideEntry' : _reflection.GeneratedProtocolMessageType('PorcelainNameOverrideEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY,
    '__module__' : 'options_pb2'
    # @@protoc_insertion_point(class_scope:v1.CustomOptions.PorcelainNameOverrideEntry)
    })
  ,

  'CommentOverrideEntry' : _reflection.GeneratedProtocolMessageType('CommentOverrideEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMOPTIONS_COMMENTOVERRIDEENTRY,
    '__module__' : 'options_pb2'
    # @@protoc_insertion_point(class_scope:v1.CustomOptions.CommentOverrideEntry)
    })
  ,

  'DeprecatedOverrideEntry' : _reflection.GeneratedProtocolMessageType('DeprecatedOverrideEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY,
    '__module__' : 'options_pb2'
    # @@protoc_insertion_point(class_scope:v1.CustomOptions.DeprecatedOverrideEntry)
    })
  ,
  'DESCRIPTOR' : _CUSTOMOPTIONS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.CustomOptions)
  })
_sym_db.RegisterMessage(CustomOptions)
_sym_db.RegisterMessage(CustomOptions.PorcelainTypeOverrideEntry)
_sym_db.RegisterMessage(CustomOptions.PorcelainNameOverrideEntry)
_sym_db.RegisterMessage(CustomOptions.CommentOverrideEntry)
_sym_db.RegisterMessage(CustomOptions.DeprecatedOverrideEntry)

TerraformDocs = _reflection.GeneratedProtocolMessageType('TerraformDocs', (_message.Message,), {
  'DESCRIPTOR' : _TERRAFORMDOCS,
  '__module__' : 'options_pb2'
  # @@protoc_insertion_point(class_scope:v1.TerraformDocs)
  })
_sym_db.RegisterMessage(TerraformDocs)

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(file_options)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_options)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_options)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_options)
  google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(oneof_options)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_options)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_options)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _FILEOPTIONS._options = None
  _FILEOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _SERVICEOPTIONS._options = None
  _SERVICEOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _METHODOPTIONS._options = None
  _METHODOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _MESSAGEOPTIONS._options = None
  _MESSAGEOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _ONEOFOPTIONS._options = None
  _ONEOFOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _FIELDOPTIONS_READONLYOVERRIDEENTRY._options = None
  _FIELDOPTIONS_READONLYOVERRIDEENTRY._serialized_options = b'8\001'
  _FIELDOPTIONS._options = None
  _FIELDOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _ENUMOPTIONS._options = None
  _ENUMOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY._options = None
  _CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY._serialized_options = b'8\001'
  _CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY._options = None
  _CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY._serialized_options = b'8\001'
  _CUSTOMOPTIONS_COMMENTOVERRIDEENTRY._options = None
  _CUSTOMOPTIONS_COMMENTOVERRIDEENTRY._serialized_options = b'8\001'
  _CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY._options = None
  _CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY._serialized_options = b'8\001'
  _CUSTOMOPTIONS._options = None
  _CUSTOMOPTIONS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _TERRAFORMDOCS._options = None
  _TERRAFORMDOCS._serialized_options = b'\372\370\263\007\022\322\363\263\007\r!json_gateway'
  _FILEOPTIONS._serialized_start=55
  _FILEOPTIONS._serialized_end=112
  _SERVICEOPTIONS._serialized_start=115
  _SERVICEOPTIONS._serialized_end=304
  _METHODOPTIONS._serialized_start=307
  _METHODOPTIONS._serialized_end=464
  _MESSAGEOPTIONS._serialized_start=467
  _MESSAGEOPTIONS._serialized_end=709
  _ONEOFOPTIONS._serialized_start=711
  _ONEOFOPTIONS._serialized_end=798
  _FIELDOPTIONS._serialized_start=801
  _FIELDOPTIONS._serialized_end=1350
  _FIELDOPTIONS_READONLYOVERRIDEENTRY._serialized_start=1270
  _FIELDOPTIONS_READONLYOVERRIDEENTRY._serialized_end=1325
  _ENUMOPTIONS._serialized_start=1352
  _ENUMOPTIONS._serialized_end=1446
  _CUSTOMOPTIONS._serialized_start=1449
  _CUSTOMOPTIONS._serialized_end=2104
  _CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY._serialized_start=1842
  _CUSTOMOPTIONS_PORCELAINTYPEOVERRIDEENTRY._serialized_end=1902
  _CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY._serialized_start=1904
  _CUSTOMOPTIONS_PORCELAINNAMEOVERRIDEENTRY._serialized_end=1964
  _CUSTOMOPTIONS_COMMENTOVERRIDEENTRY._serialized_start=1966
  _CUSTOMOPTIONS_COMMENTOVERRIDEENTRY._serialized_end=2020
  _CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY._serialized_start=2022
  _CUSTOMOPTIONS_DEPRECATEDOVERRIDEENTRY._serialized_end=2079
  _TERRAFORMDOCS._serialized_start=2106
  _TERRAFORMDOCS._serialized_end=2215
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import activities_pb2 as activities__pb2


class ActivitiesStub(object):
    """An Activity is a record of an action taken against a strongDM deployment, e.g.
    a user creation, resource deletion, sso configuration change, etc. The Activities
    service is read-only.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/v1.Activities/Get',
                request_serializer=activities__pb2.ActivityGetRequest.SerializeToString,
                response_deserializer=activities__pb2.ActivityGetResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/v1.Activities/List',
                request_serializer=activities__pb2.ActivityListRequest.SerializeToString,
                response_deserializer=activities__pb2.ActivityListResponse.FromString,
                )


class ActivitiesServicer(object):
    """An Activity is a record of an action taken against a strongDM deployment, e.g.
    a user creation, resource deletion, sso configuration change, etc. The Activities
    service is read-only.
    """

    def Get(self, request, context):
        """Get reads one Activity by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List gets a list of Activities matching a given set of criteria.
        The 'before' and 'after' filters can be used to control the time
        range of the output activities. If not provided, one week of back
        of activities will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ActivitiesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=activities__pb2.ActivityGetRequest.FromString,
                    response_serializer=activities__pb2.ActivityGetResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=activities__pb2.ActivityListRequest.FromString,
                    response_serializer=activities__pb2.ActivityListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.Activities', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Activities(object):
    """An Activity is a record of an action taken against a strongDM deployment, e.g.
    a user creation, resource deletion, sso configuration change, etc. The Activities
    service is read-only.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Activities/Get',
            activities__pb2.ActivityGetRequest.SerializeToString,
            activities__pb2.ActivityGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Activities/List',
            activities__pb2.ActivityListRequest.SerializeToString,
            activities__pb2.ActivityListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peering_groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14peering_groups.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"y\n\x19PeeringGroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x1aPeeringGroupCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16PeeringGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe6\x01\n\x17PeeringGroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x19PeeringGroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb7\x01\n\x1aPeeringGroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x17PeeringGroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd1\x01\n\x18PeeringGroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0epeering_groups\x18\x02 \x03(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"Q\n\x0cPeeringGroup\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xa1\x04\n\rPeeringGroups\x12r\n\x06\x43reate\x12\x1d.v1.PeeringGroupCreateRequest\x1a\x1e.v1.PeeringGroupCreateResponse\")\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/peeringGroups\x12y\n\x06\x44\x65lete\x12\x1d.v1.PeeringGroupDeleteRequest\x1a\x1e.v1.PeeringGroupDeleteResponse\"0\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/peeringGroups/{id}\x12m\n\x03Get\x12\x1a.v1.PeeringGroupGetRequest\x1a\x1b.v1.PeeringGroupGetResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/peeringGroups/{id}\x12k\n\x04List\x12\x1b.v1.PeeringGroupListRequest\x1a\x1c.v1.PeeringGroupListResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/peeringGroups\x1a\x45\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cPeeringGroup\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02g-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15PeeringGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PEERINGGROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupCreateRequest']
_PEERINGGROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupCreateResponse']
_PEERINGGROUPGETREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupGetRequest']
_PEERINGGROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupGetResponse']
_PEERINGGROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupDeleteRequest']
_PEERINGGROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupDeleteResponse']
_PEERINGGROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupListRequest']
_PEERINGGROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupListResponse']
_PEERINGGROUP = DESCRIPTOR.message_types_by_name['PeeringGroup']
PeeringGroupCreateRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPCREATEREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupCreateRequest)
  })
_sym_db.RegisterMessage(PeeringGroupCreateRequest)

PeeringGroupCreateResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPCREATERESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupCreateResponse)
  })
_sym_db.RegisterMessage(PeeringGroupCreateResponse)

PeeringGroupGetRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPGETREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupGetRequest)
  })
_sym_db.RegisterMessage(PeeringGroupGetRequest)

PeeringGroupGetResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPGETRESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupGetResponse)
  })
_sym_db.RegisterMessage(PeeringGroupGetResponse)

PeeringGroupDeleteRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPDELETEREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupDeleteRequest)
  })
_sym_db.RegisterMessage(PeeringGroupDeleteRequest)

PeeringGroupDeleteResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPDELETERESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupDeleteResponse)
  })
_sym_db.RegisterMessage(PeeringGroupDeleteResponse)

PeeringGroupListRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPLISTREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupListRequest)
  })
_sym_db.RegisterMessage(PeeringGroupListRequest)

PeeringGroupListResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPLISTRESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupListResponse)
  })
_sym_db.RegisterMessage(PeeringGroupListResponse)

PeeringGroup = _reflection.GeneratedProtocolMessageType('PeeringGroup', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUP,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroup)
  })
_sym_db.RegisterMessage(PeeringGroup)

_PEERINGGROUPS = DESCRIPTOR.services_by_name['PeeringGroups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025PeeringGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PEERINGGROUPCREATEREQUEST.fields_by_name['peering_group']._options = None
  _PEERINGGROUPCREATEREQUEST.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['peering_group']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPCREATERESPONSE._options = None
  _PEERINGGROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPGETREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['peering_group']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPGETRESPONSE._options = None
  _PEERINGGROUPGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPDELETEREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPDELETERESPONSE._options = None
  _PEERINGGROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPLISTREQUEST.fields_by_name['filter']._options = None
  _PEERINGGROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPLISTRESPONSE.fields_by_name['peering_groups']._options = None
  _PEERINGGROUPLISTRESPONSE.fields_by_name['peering_groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PEERINGGROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUP.fields_by_name['id']._options = None
  _PEERINGGROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUP.fields_by_name['name']._options = None
  _PEERINGGROUP.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUP._options = None
  _PEERINGGROUP._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPS._options = None
  _PEERINGGROUPS._serialized_options = b'\312\371\263\007\021\302\371\263\007\014PeeringGroup\312\371\263\007\007\322\371\263\007\002g-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\330\371\263\007\001'
  _PEERINGGROUPS.methods_by_name['Create']._options = None
  _PEERINGGROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\026\252\363\263\007\021/v1/peeringGroups'
  _PEERINGGROUPS.methods_by_name['Delete']._options = None
  _PEERINGGROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\033\252\363\263\007\026/v1/peeringGroups/{id}'
  _PEERINGGROUPS.methods_by_name['Get']._options = None
  _PEERINGGROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/peeringGroups/{id}'
  _PEERINGGROUPS.methods_by_name['List']._options = None
  _PEERINGGROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\026\252\363\263\007\021/v1/peeringGroups'
  _PEERINGGROUPCREATEREQUEST._serialized_start=55
  _PEERINGGROUPCREATEREQUEST._serialized_end=176
  _PEERINGGROUPCREATERESPONSE._serialized_start=179
  _PEERINGGROUPCREATERESPONSE._serialized_end=415
  _PEERINGGROUPGETREQUEST._serialized_start=417
  _PEERINGGROUPGETREQUEST._serialized_end=503
  _PEERINGGROUPGETRESPONSE._serialized_start=506
  _PEERINGGROUPGETRESPONSE._serialized_end=736
  _PEERINGGROUPDELETEREQUEST._serialized_start=738
  _PEERINGGROUPDELETEREQUEST._serialized_end=830
  _PEERINGGROUPDELETERESPONSE._serialized_start=833
  _PEERINGGROUPDELETERESPONSE._serialized_end=1016
  _PEERINGGROUPLISTREQUEST._serialized_start=1018
  _PEERINGGROUPLISTREQUEST._serialized_end=1110
  _PEERINGGROUPLISTRESPONSE._serialized_start=1113
  _PEERINGGROUPLISTRESPONSE._serialized_end=1322
  _PEERINGGROUP._serialized_start=1324
  _PEERINGGROUP._serialized_end=1405
  _PEERINGGROUPS._serialized_start=1408
  _PEERINGGROUPS._serialized_end=1953
# @@protoc_insertion_point(module_scope)
